Inheritance
:::::::::::

.. toctree::
   :caption: Inheritance
   :maxdepth: 2

   intro.rst
   inheritVarsAndMethods.rst
   OverrideMethods.rst
   InvokingSuperMethods.rst
   MultipleInheritance.rst
   TamagotchiRevisited.rst
   Exercises.rst
   ChapterAssessment.rst
   chapterProject.rst
